@@ -1,14 +1,14 @@
 # Copyrights 2017-2025 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.03.
+# Pod stripped from pm file by OODoc 2.02.
 # This code is part of distribution Log-Report-Template. Meta-POD processed
 # with OODoc into POD and HTML manual-pages.  See README.md
 # Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
-package Log::Report::Template;{
-our $VERSION = '1.01';
-}
+package Log::Report::Template;
+use vars '$VERSION';
+$VERSION = '1.02';
 
 use base 'Template';
 
